@@ -18,6 +18,7 @@
 #include <QPainter>
 #include <QPushButton>
 #include <QScrollArea>
+#include <QScrollBar>
 #include <QStyle>
 #include <QVBoxLayout>
 #include <QWhatsThis>
@@ -265,10 +266,15 @@ void ModuleView::addModule(MenuItem *item, const QStringList &args)
     moduleScroll->setWidgetResizable(true);
     moduleScroll->setFrameStyle(QFrame::NoFrame);
     moduleScroll->viewport()->setAutoFillBackground(false);
+    moduleScroll->horizontalScrollBar()->installEventFilter(this);
+    moduleScroll->verticalScrollBar()->installEventFilter(this);
     // Create the page
     auto page = new KPageWidgetItem(moduleScroll, data.name());
     // Provide information to the users
 
+    // set accessible name, or screen reader users will have a cryptic "LayeredPane" tabstop
+    moduleScroll->setAccessibleName(i18ndc("systemsettings", "@info:whatsthis", "Scrollable area"));
+
     if (item->isExternalAppModule()) {
         auto externalWidget = new ExternalAppModule(KService::Ptr(new KService(item->metaData().fileName())));
         moduleScroll->setWidget(externalWidget);
@@ -482,12 +488,13 @@ void ModuleView::activeModuleChanged(KPageWidgetItem *current, KPageWidgetItem *
         // TODO: make this use a real gridUnit so it will adjust to the user's font,
         // once we have a QmlEngine object such that  using it won't risk crashes!
         titleWidget->layout()->setContentsMargins(18,
-                                                  style()->pixelMetric(QStyle::PM_LayoutRightMargin),
+                                                  style()->pixelMetric(QStyle::PM_LayoutTopMargin),
                                                   style()->pixelMetric(QStyle::PM_LayoutRightMargin),
                                                   style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
     }
 
     updatePageIconHeader(current);
+    updateScrollAreaFocusPolicy();
     moduleShowDefaultsIndicators(d->mDefaultsIndicatorsVisible);
 }
 
@@ -664,4 +671,28 @@ void ModuleView::authStatusChanged(KAuth::Action::AuthStatus status)
     }
 }
 
+void ModuleView::updateScrollAreaFocusPolicy()
+{
+    KPageWidgetItem *item = d->mPageWidget->currentPage();
+    if (!item) {
+        return;
+    }
+    QScrollArea *moduleScroll = qobject_cast<QScrollArea *>(item->widget());
+    if (moduleScroll) {
+        bool scrollbarVisible = moduleScroll->horizontalScrollBar()->isVisible() || moduleScroll->verticalScrollBar()->isVisible();
+        moduleScroll->setFocusPolicy(scrollbarVisible ? Qt::FocusPolicy::StrongFocus : Qt::FocusPolicy::NoFocus);
+    }
+}
+
+bool ModuleView::eventFilter(QObject *watched, QEvent *event)
+{
+    if ((event->type() == QEvent::Show || event->type() == QEvent::Hide) && d->mPageWidget->currentPage()) {
+        QScrollArea *moduleScroll = qobject_cast<QScrollArea *>(d->mPageWidget->currentPage()->widget());
+        if (moduleScroll && (watched == moduleScroll->horizontalScrollBar() || watched == moduleScroll->verticalScrollBar())) {
+            updateScrollAreaFocusPolicy();
+        }
+    }
+    return QWidget::eventFilter(watched, event);
+}
+
 #include "moc_ModuleView.cpp"
